/*
	Copyright (C) 1994,1995	Edward Der-Hua Liu, Hsin-Chu, Taiwan
*/

#include <sys/types.h>
#include "constant.h"

#define MROW 2
#define ROW 2
#define MCOL 44
#define InAreaX (16)

#define NormalColor (0)
#define InAreaColor (1)

struct TableHead {
	char ename[CIN_ENAME_LENGTH];		/* ascii name */
	char cname[CIN_CNAME_LENGTH];		/* prompt */
	char selkey[SELECT_KEY_LENGTH];		/* select keys */
	char endkey[END_KEY_LENGTH];		/* end ekys */
	char last_full;
	char endian;
	int KeyS;		/* number of keys needed */
	int MaxPress;		/* Max len of keystroke  array30:4  cj:5 */
	int M_DUP_SEL;		/* how many keys used to select */
	int DefC;		/* Defined characters */
};

typedef struct {
  u_char key1[4];   /* If I use u_long key, the struc size will be 8 */
  u_char key2[4];
  u_char ch[2];
  char simplest;
} ITEM;

extern u_long CONVT(char *s);

#define ename(p) ((p)->ename)
#define cname(p) ((p)->cname)
#define endian(p) ((p)->endian)
#define KeyS(p) ((p)->KeyS)
#define MaxPress(p) ((p)->MaxPress)

void xprintf(char *,...);
void error(char *,...);
void p_err(char *,...);

